@@ -3,7 +3,7 @@ package Net::WhitePages;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 use LWP::Simple qw($ua get);
 use Params::Validate qw(validate);
@@ -19,6 +19,7 @@ sub new {
     $ua->agent("$class/$VERSION (" . $ua->agent . ")");
 
     bless {
+        DEBUG       => 0,
         TOKEN       => $ENV{'WHITEPAGES_TOKEN'},
         API_VERSION => '1.0',
         %$args,
@@ -107,6 +108,10 @@ sub _request {
    (my $meth = $meth[3]) =~ s/.*:://;
     my $uri = $self->_uri($meth, @_);
 
+    if ($self->{ DEBUG }) {
+        warn "[DEBUG] Calling `", $uri->canonical, "'\n";
+    }
+
     my $data = get($uri->canonical);
 
     return eval($data);
@@ -118,7 +123,7 @@ __END__
 
 =head1 NAME
 
-Net::WhitePages - A Perl interface to the WhitePages.com API
+Net::WhitePages - A Perl interface to the WhitePages.com API v1.0
 
 =head1 SYNOPSIS
 
@@ -139,7 +144,9 @@ http://developer.whitepages.com/ for a sign-up link and terms of service.
 
 WhitePages.com places strict usage limitations, which this module does
 not attempt to enforce.
-    
+
+Note that this currently only works for version 1.0 of the WhitePages.com API.
+
 =head1 METHODS
 
 =over 4
@@ -175,7 +182,7 @@ Please report bugs via the RT queue at https://rt.cpan.org/.
 
 =head1 VERSION
 
-1.02
+1.05
 
 =head1 AUTHOR
 
